@@ -14,11 +14,9 @@ import Data.Maybe
 import Data.String.Utils
 
 import Command
-import qualified Annex
 import qualified Remote
+import qualified RemoteLog
 import qualified Types.Remote as R
-import qualified GitRepo as Git
-import Utility
 import Types
 import UUID
 import Messages
@@ -26,15 +24,15 @@ import Messages
 command :: [Command]
 command = [repoCommand "initremote"
 	(paramPair paramName $
-		paramOptional $ paramRepeating $ paramKeyValue) seek
+		paramOptional $ paramRepeating paramKeyValue) seek
 	"sets up a special (non-git) remote"]
 
 seek :: [CommandSeek]
 seek = [withWords start]
 
 start :: CommandStartWords
-start ws = notBareRepo $ do
-	when (null ws) $ needname
+start ws = do
+	when (null ws) needname
 
 	(u, c) <- findByName name
 	let fullconfig = M.union config c	
@@ -45,7 +43,7 @@ start ws = notBareRepo $ do
 
 	where
 		name = head ws
-		config = Remote.keyValToConfig $ tail ws
+		config = RemoteLog.keyValToConfig $ tail ws
 		needname = do
 			let err s = error $ "Specify a name for the remote. " ++ s
 			names <- remoteNames
@@ -61,25 +59,17 @@ perform t u c = do
 
 cleanup :: UUID -> R.RemoteConfig -> CommandCleanup
 cleanup u c = do
-	Remote.configSet u c
-	g <- Annex.gitRepo
-	logfile <- Remote.remoteLog
-	liftIO $ Git.run g "add" [File logfile]
-        liftIO $ Git.run g "commit"
-                [ Params "-q --allow-empty -m"
-                , Param "git annex initremote"
-                , File logfile
-                ]
+	RemoteLog.configSet u c
         return True
 
 {- Look up existing remote's UUID and config by name, or generate a new one -}
 findByName :: String -> Annex (UUID, R.RemoteConfig)
 findByName name = do
-	m <- Remote.readRemoteLog
+	m <- RemoteLog.readRemoteLog
 	maybe generate return $ findByName' name m
 	where
 		generate = do
-			uuid <- liftIO $ genUUID
+			uuid <- liftIO genUUID
 			return (uuid, M.insert nameKey name M.empty)
 
 findByName' :: String ->  M.Map UUID R.RemoteConfig -> Maybe (UUID, R.RemoteConfig)
@@ -94,8 +84,8 @@ findByName' n m = if null matches then Nothing else Just $ head matches
 
 remoteNames :: Annex [String]
 remoteNames = do
-	m <- Remote.readRemoteLog
-	return $ catMaybes $ map ((M.lookup nameKey) . snd) $ M.toList m
+	m <- RemoteLog.readRemoteLog
+	return $ mapMaybe (M.lookup nameKey . snd) $ M.toList m
 
 {- find the specified remote type -}
 findType :: R.RemoteConfig -> Annex (R.RemoteType Annex)
