@@ -33,5 +33,5 @@ perform file = do
 	-- Checkout from HEAD to get rid of any changes that might be 
 	-- staged in the index, and get back to the previous symlink to
 	-- the content.
-	AnnexQueue.add "checkout" [Param "HEAD", Param "--"] file
+	AnnexQueue.add "checkout" [Param "HEAD", Param "--"] [file]
 	next $ return True -- no cleanup needed
