@@ -7,13 +7,10 @@
 
 module Command.Whereis where
 
-import Control.Monad.State (liftIO)
-
-import qualified Annex
 import LocationLog
 import Command
 import Messages
-import UUID
+import Remote
 import Types
 
 command :: [Command]
@@ -30,16 +27,15 @@ start file = isAnnexed file $ \(key, _) -> do
 
 perform :: Key -> CommandPerform
 perform key = do
-	g <- Annex.gitRepo
-	uuids <- liftIO $ keyLocations g key
+	uuids <- keyLocations key
 	let num = length uuids
 	showNote $ show num ++ " " ++ copiesplural num
-	if null $ uuids
+	if null uuids
 		then stop
 		else do
 			pp <- prettyPrintUUIDs uuids
-			showLongNote $ pp
-			showProgress	
+			showLongNote pp
+			showOutput
 			next $ return True
 	where
 		copiesplural 1 = "copy"
