@@ -14,47 +14,43 @@ module Remote (
 	removeKey,
 	hasKey,
 	hasKeyCheap,
-	keyPossibilities,
-	forceTrust,
 
 	remoteTypes,
 	genList,
 	byName,
-	nameToUUID,
+	prettyPrintUUIDs,
 	remotesWithUUID,
 	remotesWithoutUUID,
-
-	remoteLog,
-	readRemoteLog,
-	configSet,
-	keyValToConfig,
-	configToKeyVal,
-	
-	prop_idempotent_configEscape
+	keyPossibilities,
+	keyPossibilitiesTrusted,
+	nameToUUID,
+	showTriedRemotes,
+	showLocations,
+	forceTrust
 ) where
 
-import Control.Monad.State (liftIO)
-import Control.Monad (when, liftM, filterM)
+import Control.Monad (filterM, liftM2)
 import Data.List
 import qualified Data.Map as M
+import Data.String.Utils
 import Data.Maybe
-import Data.Char
 
 import Types
 import Types.Remote
 import UUID
 import qualified Annex
-import Locations
-import Utility
 import Config
 import Trust
 import LocationLog
+import Messages
+import RemoteLog
 
 import qualified Remote.Git
 import qualified Remote.S3
 import qualified Remote.Bup
 import qualified Remote.Directory
 import qualified Remote.Rsync
+import qualified Remote.Web
 import qualified Remote.Hook
 
 remoteTypes :: [RemoteType Annex]
@@ -64,6 +60,7 @@ remoteTypes =
 	, Remote.Bup.remote
 	, Remote.Directory.remote
 	, Remote.Rsync.remote
+	, Remote.Web.remote
 	, Remote.Hook.remote
 	]
 
@@ -91,20 +88,53 @@ genList = do
 
 {- Looks up a remote by name. (Or by UUID.) -}
 byName :: String -> Annex (Remote Annex)
-byName "" = error "no remote specified"
 byName n = do
+	res <- byName' n
+	case res of
+		Left e -> error e
+		Right r -> return r
+byName' :: String -> Annex (Either String (Remote Annex))
+byName' "" = return $ Left "no remote specified"
+byName' n = do
 	allremotes <- genList
 	let match = filter matching allremotes
-	when (null match) $ error $
-		"there is no git remote named \"" ++ n ++ "\""
-	return $ head match
+	if null match
+		then return $ Left $ "there is no git remote named \"" ++ n ++ "\""
+		else return $ Right $ head match
 	where
 		matching r = n == name r || n == uuid r
 
-{- Looks up a remote by name (or by UUID), and returns its UUID. -}
+{- Looks up a remote by name (or by UUID, or even by description),
+ - and returns its UUID. -}
 nameToUUID :: String -> Annex UUID
 nameToUUID "." = getUUID =<< Annex.gitRepo -- special case for current repo
-nameToUUID n = liftM uuid (byName n)
+nameToUUID n = do
+	res <- byName' n
+	case res of
+		Left e -> return . fromMaybe (error e) =<< byDescription
+		Right r -> return $ uuid r
+	where
+		byDescription = return . M.lookup n . invertMap =<< uuidMap
+		invertMap = M.fromList . map swap . M.toList
+		swap (a, b) = (b, a)
+
+{- Pretty-prints a list of UUIDs of remotes. -}
+prettyPrintUUIDs :: [UUID] -> Annex String
+prettyPrintUUIDs uuids = do
+	here <- getUUID =<< Annex.gitRepo
+	-- Show descriptions from the uuid log, falling back to remote names,
+	-- as some remotes may not be in the uuid log
+	m <- liftM2 M.union uuidMap $
+		return . M.fromList . map (\r -> (uuid r, name r)) =<< genList
+	return $ unwords $ map (\u -> "\t" ++ prettify m u here ++ "\n") uuids
+	where
+		prettify m u here = base ++ ishere
+			where
+				base = if not $ null $ findlog m u
+					then u ++ "  -- " ++ findlog m u
+					else u
+				ishere = if here == u then " <-- here" else ""
+		findlog m u = M.findWithDefault "" u m
 
 {- Filters a list of remotes to ones that have the listed uuids. -}
 remotesWithUUID :: [Remote Annex] -> [UUID] -> [Remote Annex]
@@ -114,19 +144,27 @@ remotesWithUUID rs us = filter (\r -> uuid r `elem` us) rs
 remotesWithoutUUID :: [Remote Annex] -> [UUID] -> [Remote Annex]
 remotesWithoutUUID rs us = filter (\r -> uuid r `notElem` us) rs
 
+{- Cost ordered lists of remotes that the LocationLog indicate may have a key.
+ -}
+keyPossibilities :: Key -> Annex [Remote Annex]
+keyPossibilities key = return . fst =<< keyPossibilities' False key
+
 {- Cost ordered lists of remotes that the LocationLog indicate may have a key.
  -
  - Also returns a list of UUIDs that are trusted to have the key
  - (some may not have configured remotes).
  -}
-keyPossibilities :: Key -> Annex ([Remote Annex], [UUID])
-keyPossibilities key = do
+keyPossibilitiesTrusted :: Key -> Annex ([Remote Annex], [UUID])
+keyPossibilitiesTrusted = keyPossibilities' True
+
+keyPossibilities' :: Bool -> Key -> Annex ([Remote Annex], [UUID])
+keyPossibilities' withtrusted key = do
 	g <- Annex.gitRepo
 	u <- getUUID g
-	trusted <- trustGet Trusted
+	trusted <- if withtrusted then trustGet Trusted else return []
 
 	-- get uuids of all remotes that are recorded to have the key
-	uuids <- liftIO $ keyLocations g key
+	uuids <- keyLocations key
 	let validuuids = filter (/= u) uuids
 
 	-- note that validuuids is assumed to not have dups
@@ -138,87 +176,33 @@ keyPossibilities key = do
 
 	return (sort validremotes, validtrusteduuids)
 
+{- Displays known locations of a key. -}
+showLocations :: Key -> [UUID] -> Annex ()
+showLocations key exclude = do
+	g <- Annex.gitRepo
+	u <- getUUID g
+	uuids <- keyLocations key
+	untrusteduuids <- trustGet UnTrusted
+	let uuidswanted = filteruuids uuids (u:exclude++untrusteduuids) 
+	let uuidsskipped = filteruuids uuids (u:exclude++uuidswanted)
+	ppuuidswanted <- Remote.prettyPrintUUIDs uuidswanted
+	ppuuidsskipped <- Remote.prettyPrintUUIDs uuidsskipped
+	showLongNote $ message ppuuidswanted ppuuidsskipped
+	where
+		filteruuids l x = filter (`notElem` x) l
+		message [] [] = "No other repository is known to contain the file."
+		message rs [] = "Try making some of these repositories available:\n" ++ rs
+		message [] us = "Also these untrusted repositories may contain the file:\n" ++ us
+		message rs us = message rs [] ++ message [] us
+
+showTriedRemotes :: [Remote Annex] -> Annex ()
+showTriedRemotes [] = return ()	
+showTriedRemotes remotes =
+	showLongNote $ "Unable to access these remotes: " ++
+		(join ", " $ map name remotes)
+
 forceTrust :: TrustLevel -> String -> Annex ()
 forceTrust level remotename = do
-	r <- Remote.nameToUUID remotename
+	r <- nameToUUID remotename
 	Annex.changeState $ \s ->
 		s { Annex.forcetrust = (r, level):Annex.forcetrust s }
-
-{- Filename of remote.log. -}
-remoteLog :: Annex FilePath
-remoteLog = do
-	g <- Annex.gitRepo
-	return $ gitStateDir g ++ "remote.log"
-
-{- Adds or updates a remote's config in the log. -}
-configSet :: UUID -> RemoteConfig -> Annex ()
-configSet u c = do
-	m <- readRemoteLog
-	l <- remoteLog
-	liftIO $ safeWriteFile l $ unlines $ sort $
-		map toline $ M.toList $ M.insert u c m
-	where
-		toline (u', c') = u' ++ " " ++ (unwords $ configToKeyVal c')
-
-{- Map of remotes by uuid containing key/value config maps. -}
-readRemoteLog :: Annex (M.Map UUID RemoteConfig)
-readRemoteLog = do
-	l <- remoteLog
-	s <- liftIO $ catch (readFile l) ignoreerror
-	return $ remoteLogParse s
-	where
-		ignoreerror _ = return ""
-
-remoteLogParse :: String -> M.Map UUID RemoteConfig
-remoteLogParse s =
-	M.fromList $ catMaybes $ map parseline $ filter (not . null) $ lines s
-	where
-		parseline l
-			| length w > 2 = Just (u, c)
-			| otherwise = Nothing
-			where
-				w = words l
-				u = w !! 0
-				c = keyValToConfig $ tail w
-
-{- Given Strings like "key=value", generates a RemoteConfig. -}
-keyValToConfig :: [String] -> RemoteConfig
-keyValToConfig ws = M.fromList $ map (/=/) ws
-	where
-		(/=/) s = (k, v)
-			where
-				k = takeWhile (/= '=') s
-				v = configUnEscape $ drop (1 + length k) s
-
-configToKeyVal :: M.Map String String -> [String]
-configToKeyVal m = map toword $ sort $ M.toList m
-	where
-		toword (k, v) = k ++ "=" ++ configEscape v
-
-configEscape :: String -> String
-configEscape = (>>= escape)
-	where
-		escape c
-			| isSpace c || c `elem` "&" = "&" ++ show (ord c) ++ ";"
-			| otherwise = [c]
-
-configUnEscape :: String -> String
-configUnEscape = unescape
-	where
-		unescape [] = []
-		unescape (c:rest)
-			| c == '&' = entity rest
-			| otherwise = c : unescape rest
-		entity s = if ok
-				then chr (read num) : unescape rest
-				else '&' : unescape s
-			where
-				num = takeWhile isNumber s
-				r = drop (length num) s
-				rest = drop 1 r
-				ok = not (null num) && 
-					not (null r) && r !! 0 == ';'
-
-{- for quickcheck -}
-prop_idempotent_configEscape :: String -> Bool
-prop_idempotent_configEscape s = s == (configUnEscape $ configEscape s)
