@@ -17,10 +17,9 @@ module UUID (
 	getUncachedUUID,
 	prepUUID,
 	genUUID,
-	prettyPrintUUIDs,
 	describeUUID,
-	uuidLog,
-	uuidMap
+	uuidMap,
+	uuidLog
 ) where
 
 import Control.Monad.State
@@ -29,25 +28,28 @@ import System.IO
 import qualified Data.Map as M
 import Data.Maybe
 
-import qualified GitRepo as Git
+import qualified Git
+import qualified Branch
 import Types
 import Types.UUID
-import Locations
 import qualified Annex
-import Utility
 import qualified SysConfig
 import Config
 
 configkey :: String
 configkey = "annex.uuid"
 
+{- Filename of uuid.log. -}
+uuidLog :: FilePath
+uuidLog = "uuid.log"
+
 {- Generates a UUID. There is a library for this, but it's not packaged,
  - so use the command line tool. -}
 genUUID :: IO UUID
 genUUID = liftIO $ pOpen ReadFromPipe command params $ \h -> hGetLine h
 	where
 		command = SysConfig.uuid
-		params = if (command == "uuid")
+		params = if command == "uuid"
 			-- request a random uuid be generated
 			then ["-m"]
 			-- uuidgen generates random uuid by default
@@ -80,49 +82,25 @@ prepUUID :: Annex ()
 prepUUID = do
 	u <- getUUID =<< Annex.gitRepo
 	when ("" == u) $ do
-		uuid <- liftIO $ genUUID
+		uuid <- liftIO genUUID
 		setConfig configkey uuid
 
-{- Pretty-prints a list of UUIDs -}
-prettyPrintUUIDs :: [UUID] -> Annex String
-prettyPrintUUIDs uuids = do
-	here <- getUUID =<< Annex.gitRepo
-	m <- uuidMap
-	return $ unwords $ map (\u -> "\t" ++ prettify m u here ++ "\n") uuids
-	where
-		prettify m u here = base ++ ishere
-			where
-				base = if not $ null $ findlog m u
-					then u ++ "  -- " ++ findlog m u
-					else u
-				ishere = if here == u then " <-- here" else ""
-		findlog m u = M.findWithDefault "" u m
-
 {- Records a description for a uuid in the uuidLog. -}
 describeUUID :: UUID -> String -> Annex ()
 describeUUID uuid desc = do
 	m <- uuidMap
 	let m' = M.insert uuid desc m
-	logfile <- uuidLog
-	liftIO $ safeWriteFile logfile (serialize m')
+	Branch.change uuidLog (serialize m')
 	where
 		serialize m = unlines $ map (\(u, d) -> u++" "++d) $ M.toList m
 
 {- Read and parse the uuidLog into a Map -}
 uuidMap :: Annex (M.Map UUID String)
 uuidMap = do
-	logfile <- uuidLog
-	s <- liftIO $ catch (readFile logfile) ignoreerror
+	s <- Branch.get uuidLog
 	return $ M.fromList $ map pair $ lines s
 	where
 		pair l =
 			if 1 < length (words l)
 				then (head $ words l, unwords $ drop 1 $ words l)
 				else ("", "")
-		ignoreerror _ = return ""
-
-{- Filename of uuid.log. -}
-uuidLog :: Annex FilePath
-uuidLog = do
-	g <- Annex.gitRepo
-	return $ gitStateDir g ++ "uuid.log"
