@@ -11,12 +11,14 @@ import Types
 import Version
 import qualified Upgrade.V0
 import qualified Upgrade.V1
+import qualified Upgrade.V2
 
 {- Uses the annex.version git config setting to automate upgrades. -}
 upgrade :: Annex Bool
 upgrade = do
 	version <- getVersion
 	case version of
-		"0" -> Upgrade.V0.upgrade
-		"1" -> Upgrade.V1.upgrade
+		Just "0" -> Upgrade.V0.upgrade
+		Just "1" -> Upgrade.V1.upgrade
+		Just "2" -> Upgrade.V2.upgrade
 		_ -> return True
